@@ -7,8 +7,8 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 15, 18),
-    __version__='0.15.18',
+    version_info=(0, 15, 35),
+    __version__='0.15.35',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
@@ -16,7 +16,7 @@ _package_data = dict(
     since=2014,
     extras_require={':platform_python_implementation=="CPython" and python_version<="2.7"': [
             'ruamel.ordereddict',
-        ], 'jinja2': ['ruamel.yaml.jinja2>=0.2']},
+        ], 'jinja2': ['ruamel.yaml.jinja2>=0.2'], 'docs': ['ryd']},
     ext_modules=[dict(
             name='_ruamel_yaml',
             src=['ext/_ruamel_yaml.c', 'ext/api.c', 'ext/writer.c', 'ext/dumper.c',
@@ -27,8 +27,8 @@ _package_data = dict(
                     'ext/emitter.c',
             ],
             lib=[],
-            test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
         )],
+            # test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
     classifiers=[
             'Programming Language :: Python :: 2.7',
             'Programming Language :: Python :: 3.3',
